==> ioc-liturgical-react-1.0.3.tgz: package/es/modules/NewEntryForm.js <==
var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import MessageIcons from '../helpers/MessageIcons';
import Form from "react-jsonschema-form";
import { Button } from 'react-bootstrap';
import FontAwesome from 'react-fontawesome';
import axios from 'axios';

/**
 * This component provides a schema based form editor
 */
var NewEntryForm = (_temp = _class = function (_React$Component) {
  _inherits(NewEntryForm, _React$Component);

  function NewEntryForm(props) {
    _classCallCheck(this, NewEntryForm);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        thisClass: labels[labelTopics.NewEntryForm],
        button: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        search: labels[labelTopics.search]
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      formData: _this.props.formData
    };

    _this.handleStateChange = _this.handleStateChange.bind(_this);
    _this.onChange = _this.onChange.bind(_this);
    _this.onSubmit = _this.onSubmit.bind(_this);
    return _this;
  }

  // if we need to do something after setState, do it here...


  NewEntryForm.prototype.render = function render() {
    return React.createElement(
      'div',
      { className: 'App-New-Component-Template' },
      React.createElement(
        Form,
        { schema: this.props.schema,
          uiSchema: this.props.uiSchema,
          formData: this.state.formData,
          onSubmit: this.onSubmit,
          onChange: this.onChange
        },
        React.createElement(
          'div',
          null,
          React.createElement(
            Button,
            {
              bsStyle: 'primary',
              type: 'submit'
            },
            this.state.labels.button.submit
          ),
          React.createElement(
            'span',
            { className: 'App App-message' },
            React.createElement(FontAwesome, {
              name: this.state.messageIcon }),
            this.state.message
          )
        )
      )
    );
  };

  return NewEntryForm;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {};

  this.componentDidMount = function () {
    // make any initial function calls here...
  };

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;
    _this2.setState(function (prevState, props) {
      return {
        labels: {
          thisClass: labels[labelTopics.NewEntryForm],
          button: labels[labelTopics.button],
          messages: labels[labelTopics.messages],
          search: labels[labelTopics.search]
        },
        message: labels[labelTopics.messages].initial
      };
    }, function () {
      return this.handleStateChange("place holder");
    });
  };

  this.handleStateChange = function (parm) {
    // call a function if needed
  };

  this.onChange = function (_ref) {
    var formData = _ref.formData;

    _this2.setState({
      message: _this2.state.labels.search.creating,
      messageIcon: _this2.state.messageIcons.info,
      formData: formData
    });
  };

  this.onSubmit = function (_ref2) {
    var formData = _ref2.formData;

    _this2.setState({
      message: _this2.state.labels.search.creating,
      messageIcon: _this2.state.messageIcons.info
    });

    var config = {
      auth: {
        username: _this2.props.session.userInfo.username,
        password: _this2.props.session.userInfo.password
      }
    };
    var path = _this2.props.session.restServer + _this2.props.path;
    axios.post(path, formData, config).then(function (response) {
      console.log("New Entry Form");
      console.log(formData);
      _this2.setState({
        message: _this2.state.labels.search.created,
        formData: formData
      });
      if (_this2.props.onSubmit) {
        _this2.props.onSubmit(formData);
      }
    }).catch(function (error) {
      var message = error.response.statusText;
      var messageIcon = _this2.state.messageIcons.error;
      _this2.setState({ data: message, message: message, messageIcon: messageIcon });
    });
  };
}, _temp);


process.env.NODE_ENV !== "production" ? NewEntryForm.propTypes = {
  session: PropTypes.object.isRequired,
  path: PropTypes.string.isRequired,
  schema: PropTypes.object.isRequired,
  uiSchema: PropTypes.object.isRequired,
  formData: PropTypes.object.isRequired,
  onSubmit: PropTypes.func
} : void 0;

// set default values for props here
NewEntryForm.defaultProps = {
  languageCode: "en"
};

export default NewEntryForm;

==> ioc-liturgical-react-1.0.6.tgz: package/es/modules/NewEntryForm.js <==
var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from 'react';
import PropTypes from 'prop-types';
import MessageIcons from '../helpers/MessageIcons';
import Form from "react-jsonschema-form";
import { Button } from 'react-bootstrap';
import FontAwesome from 'react-fontawesome';
import axios from 'axios';
import IdManager from "../helpers/IdManager";

/**
 * This component provides a schema based form editor
 */
var NewEntryForm = (_temp = _class = function (_React$Component) {
  _inherits(NewEntryForm, _React$Component);

  function NewEntryForm(props) {
    _classCallCheck(this, NewEntryForm);

    var _this = _possibleConstructorReturn(this, _React$Component.call(this, props));

    _initialiseProps.call(_this);

    var labels = props.session.labels;
    var labelTopics = props.session.labelTopics;

    _this.state = {
      labels: {
        thisClass: labels[labelTopics.NewEntryForm],
        button: labels[labelTopics.button],
        messages: labels[labelTopics.messages],
        search: labels[labelTopics.search]
      },
      messageIcons: MessageIcons.getMessageIcons(),
      messageIcon: MessageIcons.getMessageIcons().info,
      message: labels[labelTopics.messages].initial,
      formData: _this.props.formData
    };

    _this.handleStateChange = _this.handleStateChange.bind(_this);
    _this.onChange = _this.onChange.bind(_this);
    _this.onSubmit = _this.onSubmit.bind(_this);
    return _this;
  }

  // if we need to do something after setState, do it here...


  NewEntryForm.prototype.render = function render() {
    return React.createElement(
      'div',
      { className: 'App-New-Component-Template' },
      React.createElement(
        Form,
        { schema: this.props.schema,
          uiSchema: this.props.uiSchema,
          formData: this.state.formData,
          onSubmit: this.onSubmit,
          onChange: this.onChange
        },
        React.createElement(
          'div',
          null,
          React.createElement(
            Button,
            {
              bsStyle: 'primary',
              type: 'submit'
            },
            this.state.labels.button.submit
          ),
          React.createElement(
            'span',
            { className: 'App App-message' },
            React.createElement(FontAwesome, {
              name: this.state.messageIcon }),
            this.state.message
          )
        )
      )
    );
  };

  return NewEntryForm;
}(React.Component), _initialiseProps = function _initialiseProps() {
  var _this2 = this;

  this.componentWillMount = function () {};

  this.componentDidMount = function () {
    // make any initial function calls here...
  };

  this.componentWillReceiveProps = function (nextProps) {
    var labels = nextProps.session.labels;
    var labelTopics = nextProps.session.labelTopics;
    _this2.setState(function (prevState, props) {
      return {
        labels: {
          thisClass: labels[labelTopics.NewEntryForm],
          button: labels[labelTopics.button],
          messages: labels[labelTopics.messages],
          search: labels[labelTopics.search]
        },
        message: labels[labelTopics.messages].initial,
        formData: _this2.props.formData
      };
    }, function () {
      return this.handleStateChange("place holder");
    });
  };

  this.handleStateChange = function (parm) {
    // call a function if needed
  };

  this.onChange = function (_ref) {
    var formData = _ref.formData;

    _this2.setState({
      message: _this2.state.labels.search.initial,
      messageIcon: _this2.state.messageIcons.info,
      formData: formData
    });
  };

  this.onSubmit = function (_ref2) {
    var formData = _ref2.formData;

    _this2.setState({
      message: _this2.state.labels.search.creating,
      messageIcon: _this2.state.messageIcons.info
    });

    var config = {
      auth: {
        username: _this2.props.session.userInfo.username,
        password: _this2.props.session.userInfo.password
      }
    };
    var path = _this2.props.session.restServer + _this2.props.path;
    axios.post(path, formData, config).then(function (response) {
      _this2.setState({
        message: _this2.state.labels.search.created,
        formData: formData
      });
    }).catch(function (error) {
      var message = "";
      var messageIcon = _this2.state.messageIcons.error;
      if (error) {
        if (error.response) {
          message = error.response.statusText;
        } else {
          message = JSON.stringify(error);
        }
      } else {
        message = "unknown error";
      }
      _this2.setState({ data: message, message: message, messageIcon: messageIcon });
    });
  };
}, _temp);


process.env.NODE_ENV !== "production" ? NewEntryForm.propTypes = {
  session: PropTypes.object.isRequired,
  path: PropTypes.string.isRequired,
  schema: PropTypes.object.isRequired,
  uiSchema: PropTypes.object.isRequired,
  formData: PropTypes.object.isRequired,
  onSubmit: PropTypes.func
} : void 0;

// set default values for props here
NewEntryForm.defaultProps = {
  languageCode: "en"
};

export default NewEntryForm;
